==> dokuwiki_0.0.20061106.orig.tar.gz: dokuwiki-2006-11-06/inc/lang/ar/lang.php <==
<?php
/**
 * Arabic language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author     Mostafa Hussein <mostafa@gmail.com>
 */
$lang['encoding']   = 'utf-8';
$lang['direction']  = 'rtl';

$lang['btn_edit']   = 'حرر هذه الصفحة';
$lang['btn_source'] = 'اعرض مصدر الصفحة';
$lang['btn_show']   = 'أعرض الصفحة';
$lang['btn_create'] = 'أنشيء هذه الصفحة';
$lang['btn_search'] = 'بحث';
$lang['btn_save']   = 'حفظ';
$lang['btn_preview']= 'عرض التعديلات';
$lang['btn_top']    = 'لأعلى';
$lang['btn_newer']  = '<< أكثر حداثة';
$lang['btn_older']  = 'أقل حداثة >>';
$lang['btn_revs']   = 'نسخ قديمة';
$lang['btn_recent'] = 'أحدث التعديلات';
$lang['btn_upload'] = 'تحميل';
$lang['btn_cancel'] = 'إلغاء';
$lang['btn_index']  = 'فهرس';
$lang['btn_secedit']= 'حرر';
$lang['btn_login']  = 'دخول';
$lang['btn_logout'] = 'خروج';
$lang['btn_admin']  = 'المدير';
$lang['btn_update'] = 'تحديث';
$lang['btn_delete'] = 'مسح';
$lang['btn_back']   = 'رجوع';
$lang['btn_backlink']    = "إرتباطات";
$lang['btn_backtomedia'] = 'رجوع الى أختيار ملف الميديا';
$lang['btn_subscribe']   = 'أشترك فى التعديلات';
$lang['btn_unsubscribe'] = 'الغى الأشتراك فى التعديلات';

$lang['loggedinas'] = 'دخول بأسم';
$lang['user']       = 'أسم المستخدم';
$lang['pass']       = 'كلمة السر';
$lang['passchk']    = 'مرة أخرى';
$lang['remember']   = 'تذكرني';
$lang['fullname']   = 'ألأسم بالكامل';
$lang['email']      = 'بريد ألكتروني';
$lang['register']   = 'سجل';
$lang['badlogin']   = 'عذرا، أسم المستخدم أو كلمة السر غير صحيحة.';

$lang['regmissing'] = 'عذرا، يجب ملئ جميع الخانات.';
$lang['reguexists'] = 'عذرا، يوجد مستخدم بنفس الأسم.';
$lang['regsuccess'] = 'تم تسجيل أسم المستخدم و أرسال كلمة السر عبر البريد.';
$lang['regsuccess2']= 'تم تسجيل أسم المستخدم.';
$lang['regmailfail']= 'هناك خطأ فى أرسال بريد كلمة السر. برجاء مخاطبة المدير!';
$lang['regbadmail'] = 'البريد المعطى به خطأ - إذا كان هناك خطأ, خاطب المدير';
$lang['regbadpass'] = 'كلمتى السر غير متطابقتان, جرب مرة أخرى.';
$lang['regpwmail']  = 'كلمة سر دوكيويكي الخاصة بك.';
$lang['reghere']    = 'ليس لديك حساب؟ فقط أحصل علية';

$lang['txt_upload']   = 'أختر ملف للتحميل';
$lang['txt_filename'] = '(أدخل أسم الويكي (أختيارى';
$lang['txt_overwrt']  = 'أكتب على ملف موجود';
$lang['lockedby']     = 'حاليا مقفول بواسطة';
$lang['lockexpire']   = 'سينتهى القفل فى';
$lang['willexpire']   = ' سينتهى قفل تحرير هذه الصفحه فى خلال دقيقة.\n لتجنب التعارض أستخدم زر عرض التعديلات  لبدئ القفل من جديد.';

$lang['notsavedyet'] = 'التغيرات التى لم تحفظ ستفقد.\n أكمل؟';

$lang['rssfailed']   = 'خطأ ما حدث أثناء جلب ملف التغذية:';
$lang['nothingfound']= 'لا يوجد شيء.';

$lang['mediaselect'] = 'أختيار ملف ميديا';
$lang['fileupload']  = 'تحميل ملف ميديا';
$lang['uploadsucc']  = 'نجح التحميل';
$lang['uploadfail']  = 'التحميل فشل. ربما خطأ فى التراخيص؟';
$lang['uploadwrong'] = 'ممنوع التحميل. نوع الملف مرفوض!';
$lang['uploadexist'] = 'الملف موجود. لن أعمل شيء.';
$lang['deletesucc']  = 'الملف "%s" تم مسحة.';
$lang['deletefail']  = '"%s" لا يمكن مسحها - تأكد من تراخيصك.';
$lang['mediainuse']  = 'الملف "%s" لم يتم مسحه - مازال متواجد.';
$lang['namespaces']  = 'فضاء التسمية';
$lang['mediafiles']  = 'ملفات متواجدة فى';

$lang['reference']   = 'مراجع لـ';
$lang['ref_inuse']   = 'لا يمكن مسح الملف، لأنه مستخدم من قبل الصفاحات التالية:';
$lang['ref_hidden']  = 'بعض المراجع لصفاحات لا تملك ترخيص برؤيتها';

$lang['hits']       = 'زوار';
$lang['quickhits']  = 'صفحات بهذا الأسم';
$lang['toc']        = 'قائمة المحتويات';
$lang['current']    = 'حالى';
$lang['yours']      = 'نسختك';
$lang['diff']       = 'مقارنة بالنسخة الحالية';
$lang['line']       = 'سطر';
$lang['breadcrumb'] = 'أثر';
$lang['lastmod']    = 'أخر تعديل';
$lang['by']         = 'بواسطة';
$lang['deleted']    = 'مسحت';
$lang['created']    = 'إنشاء';
$lang['restored']   = 'عودة لنسخة قديمة';
$lang['summary']    = 'ملخص التحرير';

$lang['mail_newpage'] = 'أضافة صفحة:';
$lang['mail_changed'] = 'تعديل صفحة:';

$lang['nosmblinks'] = ' الروابط لمجلدات ويندوز مشاعة تعمل فقط مع متصفح مايكروسفت Internet Explorer. \n ما زال بإمكانك قص و لزق الرابط.';

$lang['qb_alert']   = 'برجاء إدخال النص المراد صياغتة.\n سيتم إضافة فى أخر الصفحة.';
$lang['qb_bold']    = 'نص عريض';
$lang['qb_italic']  = 'نص مائل';
$lang['qb_underl']  = 'نص تحتة خط';
$lang['qb_code']    = 'نص مصدرى';
$lang['qb_strike']  = 'نص مشطوب';
$lang['qb_h1']      = 'عنوان مستوى أول';
$lang['qb_h2']      = 'عنوان مستوى ثانى';
$lang['qb_h3']      = 'عنوان مستوى ثالث';
$lang['qb_h4']      = 'عنوان مستوى رابع';
$lang['qb_h5']      = 'عنوان مستوى خامس';
$lang['qb_link']    = 'رابط داخلى';
$lang['qb_extlink'] = 'رابط خارجى';
$lang['qb_hr']      = 'سطر عرضى';
$lang['qb_ol']      = 'بند فى قائمة مرتبة';
$lang['qb_ul']      = 'بند فى قائمة بلا ترتيب';
$lang['qb_media']   = 'أضف صور و ملفات أخرى';
$lang['qb_sig']     = 'أضف توقيعك';

$lang['del_confirm']= 'مسح؟';
$lang['admin_register']= 'أضف مستخدم جديد';

$lang['spell_start'] = 'تدقيق إملائى';
$lang['spell_stop']  = 'أكمل التحرير';
$lang['spell_wait']  = 'برجاء الأنتظار...';
$lang['spell_noerr'] = 'لا توجد أخطاء';
$lang['spell_nosug'] = 'لايوجد أقتراحات';
$lang['spell_change']= 'تعديل';

$lang['metaedit']    = 'حرر البيانات الشمولية ';
$lang['metasaveerr'] = 'فشل كتابة البيانات الشمولية';
$lang['metasaveok']  = 'تم حفظ البيانت الشمولية';
$lang['img_backto']  = 'العودة الى';
$lang['img_title']   = 'عنوان';
$lang['img_caption'] = 'ملخص الصورة';
$lang['img_date']    = 'تاريخ';
$lang['img_fname']   = 'أسم ملف';
$lang['img_fsize']   = 'حجم';
$lang['img_artist']  = 'المصور';
$lang['img_copyr']   = 'حقوق النسخ';
$lang['img_format']  = 'صيغ رسومية';
$lang['img_camera']  = 'الكاميرا';
$lang['img_keywords']= 'كلمات مفتاحية';

$lang['subscribe_success']  = 'تم أضافة %s لقائمة الأشتراكات %s';
$lang['subscribe_error']    = 'خطأ فى أضافة %s لقائمة الأضافة %s';
$lang['subscribe_noaddress']= 'لا يوجد عنوان مرفق مع بيانات تسجيلك, لا يمكن أضافتك لقائمة أشتراكات';
$lang['unsubscribe_success']= 'تم حذف%s من قائمة الأشتراكات %s';
$lang['unsubscribe_error']  = 'خطأ فى حذف %s من قائمة الأشتراكات %s';

//Setup VIM: ex: et ts=2 enc=utf-8 :

==> dokuwiki_0.0.20070626b.orig.tar.gz: dokuwiki-2007-06-26b/inc/lang/ar/lang.php <==
<?php
/**
 * Arabic language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author     Mostafa Hussein <mostafa@gmail.com>
 */
$lang['encoding']   = 'utf-8';
$lang['direction']  = 'rtl';
$lang['doublequoteopening']  = '“';//&ldquo;
$lang['doublequoteclosing']  = '”';//&rdquo;
$lang['singlequoteopening']  = '‘';//&lsquo;
$lang['singlequoteclosing']  = '’';//&rsquo;

$lang['btn_edit']   = 'حرر هذه الصفحة';
$lang['btn_source'] = 'اعرض مصدر الصفحة';
$lang['btn_show']   = 'أعرض الصفحة';
$lang['btn_create'] = 'أنشيء هذه الصفحة';
$lang['btn_search'] = 'بحث';
$lang['btn_save']   = 'حفظ';
$lang['btn_preview']= 'عرض التعديلات';
$lang['btn_top']    = 'لأعلى';
$lang['btn_newer']  = '<< أكثر حداثة';
$lang['btn_older']  = 'أقل حداثة >>';
$lang['btn_revs']   = 'نسخ قديمة';
$lang['btn_recent'] = 'أحدث التعديلات';
$lang['btn_upload'] = 'تحميل';
$lang['btn_cancel'] = 'إلغاء';
$lang['btn_index']  = 'فهرس';
$lang['btn_secedit']= 'حرر';
$lang['btn_login']  = 'دخول';
$lang['btn_logout'] = 'خروج';
$lang['btn_admin']  = 'المدير';
$lang['btn_update'] = 'تحديث';
$lang['btn_delete'] = 'مسح';
$lang['btn_back']   = 'رجوع';
$lang['btn_backlink']    = "إرتباطات";
$lang['btn_backtomedia'] = 'رجوع الى أختيار ملف الميديا';
$lang['btn_subscribe']   = 'أشترك فى التعديلات';
$lang['btn_unsubscribe'] = 'الغى الأشتراك فى التعديلات';

$lang['loggedinas'] = 'دخول بأسم';
$lang['user']       = 'أسم المستخدم';
$lang['pass']       = 'كلمة السر';
$lang['passchk']    = 'مرة أخرى';
$lang['remember']   = 'تذكرني';
$lang['fullname']   = 'ألأسم بالكامل';
$lang['email']      = 'بريد ألكتروني';
$lang['register']   = 'سجل';
$lang['badlogin']   = 'عذرا، أسم المستخدم أو كلمة السر غير صحيحة.';

$lang['regmissing'] = 'عذرا، يجب ملئ جميع الخانات.';
$lang['reguexists'] = 'عذرا، يوجد مستخدم بنفس الأسم.';
$lang['regsuccess'] = 'تم تسجيل أسم المستخدم و أرسال كلمة السر عبر البريد.';
$lang['regsuccess2']= 'تم تسجيل أسم المستخدم.';
$lang['regmailfail']= 'هناك خطأ فى أرسال بريد كلمة السر. برجاء مخاطبة المدير!';
$lang['regbadmail'] = 'البريد المعطى به خطأ - إذا كان هناك خطأ, خاطب المدير';
$lang['regbadpass'] = 'كلمتى السر غير متطابقتان, جرب مرة أخرى.';
$lang['regpwmail']  = 'كلمة سر دوكيويكي الخاصة بك.';
$lang['reghere']    = 'ليس لديك حساب؟ فقط أحصل علية';

$lang['txt_upload']   = 'أختر ملف للتحميل';
$lang['txt_filename'] = '(أدخل أسم الويكي (أختيارى';
$lang['txt_overwrt']  = 'أكتب على ملف موجود';
$lang['lockedby']     = 'حاليا مقفول بواسطة';
$lang['lockexpire']   = 'سينتهى القفل فى';
$lang['willexpire']   = ' سينتهى قفل تحرير هذه الصفحه فى خلال دقيقة.\n لتجنب التعارض أستخدم زر عرض التعديلات  لبدئ القفل من جديد.';

$lang['notsavedyet'] = 'التغيرات التى لم تحفظ ستفقد.\n أكمل؟';

$lang['rssfailed']   = 'خطأ ما حدث أثناء جلب ملف التغذية:';
$lang['nothingfound']= 'لا يوجد شيء.';

$lang['mediaselect'] = 'أختيار ملف ميديا';
$lang['fileupload']  = 'تحميل ملف ميديا';
$lang['uploadsucc']  = 'نجح التحميل';
$lang['uploadfail']  = 'التحميل فشل. ربما خطأ فى التراخيص؟';
$lang['uploadwrong'] = 'ممنوع التحميل. نوع الملف مرفوض!';
$lang['uploadexist'] = 'الملف موجود. لن أعمل شيء.';
$lang['deletesucc']  = 'الملف "%s" تم مسحة.';
$lang['deletefail']  = '"%s" لا يمكن مسحها - تأكد من تراخيصك.';
$lang['mediainuse']  = 'الملف "%s" لم يتم مسحه - مازال متواجد.';
$lang['namespaces']  = 'فضاء التسمية';
$lang['mediafiles']  = 'ملفات متواجدة فى';

$lang['reference']   = 'مراجع لـ';
$lang['ref_inuse']   = 'لا يمكن مسح الملف، لأنه مستخدم من قبل الصفاحات التالية:';
$lang['ref_hidden']  = 'بعض المراجع لصفاحات لا تملك ترخيص برؤيتها';

$lang['hits']       = 'زوار';
$lang['quickhits']  = 'صفحات بهذا الأسم';
$lang['toc']        = 'قائمة المحتويات';
$lang['current']    = 'حالى';
$lang['yours']      = 'نسختك';
$lang['diff']       = 'مقارنة بالنسخة الحالية';
$lang['line']       = 'سطر';
$lang['breadcrumb'] = 'أثر';
$lang['lastmod']    = 'أخر تعديل';
$lang['by']         = 'بواسطة';
$lang['deleted']    = 'مسحت';
$lang['created']    = 'إنشاء';
$lang['restored']   = 'عودة لنسخة قديمة';
$lang['summary']    = 'ملخص التحرير';

$lang['mail_newpage'] = 'أضافة صفحة:';
$lang['mail_changed'] = 'تعديل صفحة:';

$lang['nosmblinks'] = ' الروابط لمجلدات ويندوز مشاعة تعمل فقط مع متصفح مايكروسفت Internet Explorer. \n ما زال بإمكانك قص و لزق الرابط.';

$lang['qb_alert']   = 'برجاء إدخال النص المراد صياغتة.\n سيتم إضافة فى أخر الصفحة.';
$lang['qb_bold']    = 'نص عريض';
$lang['qb_italic']  = 'نص مائل';
$lang['qb_underl']  = 'نص تحتة خط';
$lang['qb_code']    = 'نص مصدرى';
$lang['qb_strike']  = 'نص مشطوب';
$lang['qb_h1']      = 'عنوان مستوى أول';
$lang['qb_h2']      = 'عنوان مستوى ثانى';
$lang['qb_h3']      = 'عنوان مستوى ثالث';
$lang['qb_h4']      = 'عنوان مستوى رابع';
$lang['qb_h5']      = 'عنوان مستوى خامس';
$lang['qb_link']    = 'رابط داخلى';
$lang['qb_extlink'] = 'رابط خارجى';
$lang['qb_hr']      = 'سطر عرضى';
$lang['qb_ol']      = 'بند فى قائمة مرتبة';
$lang['qb_ul']      = 'بند فى قائمة بلا ترتيب';
$lang['qb_media']   = 'أضف صور و ملفات أخرى';
$lang['qb_sig']     = 'أضف توقيعك';

$lang['del_confirm']= 'مسح؟';
$lang['admin_register']= 'أضف مستخدم جديد';

$lang['spell_start'] = 'تدقيق إملائى';
$lang['spell_stop']  = 'أكمل التحرير';
$lang['spell_wait']  = 'برجاء الأنتظار...';
$lang['spell_noerr'] = 'لا توجد أخطاء';
$lang['spell_nosug'] = 'لايوجد أقتراحات';
$lang['spell_change']= 'تعديل';

$lang['metaedit']    = 'حرر البيانات الشمولية ';
$lang['metasaveerr'] = 'فشل كتابة البيانات الشمولية';
$lang['metasaveok']  = 'تم حفظ البيانت الشمولية';
$lang['img_backto']  = 'العودة الى';
$lang['img_title']   = 'عنوان';
$lang['img_caption'] = 'ملخص الصورة';
$lang['img_date']    = 'تاريخ';
$lang['img_fname']   = 'أسم ملف';
$lang['img_fsize']   = 'حجم';
$lang['img_artist']  = 'المصور';
$lang['img_copyr']   = 'حقوق النسخ';
$lang['img_format']  = 'صيغ رسومية';
$lang['img_camera']  = 'الكاميرا';
$lang['img_keywords']= 'كلمات مفتاحية';

$lang['subscribe_success']  = 'تم أضافة %s لقائمة الأشتراكات %s';
$lang['subscribe_error']    = 'خطأ فى أضافة %s لقائمة الأضافة %s';
$lang['subscribe_noaddress']= 'لا يوجد عنوان مرفق مع بيانات تسجيلك, لا يمكن أضافتك لقائمة أشتراكات';
$lang['unsubscribe_success']= 'تم حذف%s من قائمة الأشتراكات %s';
$lang['unsubscribe_error']  = 'خطأ فى حذف %s من قائمة الأشتراكات %s';

//Setup VIM: ex: et ts=2 enc=utf-8 :
